@@ -2,7 +2,7 @@
  * VLCAppCoordinator.h
  * VLC for iOS
  *****************************************************************************
- * Copyright (c) 2022 VideoLAN. All rights reserved.
+ * Copyright (c) 2022-2023 VideoLAN. All rights reserved.
  * $Id$
  *
  * Author: Felix Paul Kühne <fkuehne # videolan.org>
@@ -14,22 +14,35 @@
 
 NS_ASSUME_NONNULL_BEGIN
 
+#if TARGET_OS_IOS
 @class MediaLibraryService;
 @class VLCRendererDiscovererManager;
 @class VLCMLMedia;
+#endif
+@class VLCFavoriteService;
+
+
+@class VLCHTTPUploaderController;
 
 @interface VLCAppCoordinator : NSObject
 
 + (nonnull instancetype)sharedInstance;
 
+@property (readonly) VLCHTTPUploaderController *httpUploaderController;
+@property (readonly) VLCFavoriteService *favoriteService;
+
+#if TARGET_OS_IOS
 @property (readonly) MediaLibraryService *mediaLibraryService;
 @property (readonly) VLCRendererDiscovererManager *rendererDiscovererManager;
 
+@property (nullable) UIWindow *externalWindow;
+
 - (void)setTabBarController:(UITabBarController *)tabBarController;
 
 - (void)handleShortcutItem:(UIApplicationShortcutItem *)shortcutItem;
 
 - (VLCMLMedia *)mediaForUserActivity:(NSUserActivity *)userActivity;
+#endif
 
 @end
 
