@@ -213,6 +213,8 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
     }
 
     func scrollViewDidScroll(_ scrollView: UIScrollView) {
+        scrollView.isScrollEnabled = isMediaBeingPlayed ? false : true
+
         if scrollView.contentOffset.x < 0 {
             scrollView.contentOffset.x = 0
             hasXGoneNegative = true
@@ -282,6 +284,9 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
                 NotificationCenter.default.addObserver(forName: NSNotification.Name(rawValue: VLCPlaybackServicePlaybackDidResume),
                                                        object: nil, queue: OperationQueue.main, using: {_ in
                     self.animateCurrentlyPlayingState()
+                    if let parentCollectionView = self.superview as? UICollectionView {
+                        parentCollectionView.reloadData()
+                    }
                 })
                 animateCurrentlyPlayingState()
                 backupThumbnail = audiotrack.thumbnailImage()
@@ -390,7 +395,7 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
         newLabel.isHidden = true
         titleLabel.text = playlist.name
         accessibilityLabel = playlist.accessibilityText()
-        sizeDescriptionLabel.text = playlist.numberOfTracksString()
+        sizeDescriptionLabel.text = playlist.numberOfTracksString() + " · " + playlist.durationString()
         thumbnailView.layer.cornerRadius = 3
         thumbnailView.image = playlist.thumbnail()
         dragIndicatorImageView.image = UIImage(named: "disclosureChevron")
@@ -411,7 +416,7 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
             return
         }
 
-        sizeDescriptionLabel.text = String(format: "%@ — %@", mediaGroup.numberOfTracksString(), mediaGroup.mediaDuration())
+        sizeDescriptionLabel.text = String(format: "%@ · %@", mediaGroup.numberOfTracksString(), mediaGroup.mediaDuration())
         titleLabel.text = mediaGroup.title()
         accessibilityLabel = mediaGroup.accessibilityText()
 
@@ -480,8 +485,12 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
 
     private func setupGestureRecognizer() {
         let mediaTapGesture = UITapGestureRecognizer(target: self, action: #selector(mediaTapped(_:)))
-
         scrollContentView.addGestureRecognizer(mediaTapGesture)
+
+        // Add tap gesture recognizer to disable the item selection when tapping on the drag image view
+        let tapGestureRecognizer = UITapGestureRecognizer(target: self, action: nil)
+        dragIndicatorImageView.addGestureRecognizer(tapGestureRecognizer)
+        dragIndicatorImageView.isUserInteractionEnabled = true
     }
 
     @objc private func mediaTapped(_ sender: UITapGestureRecognizer) {
@@ -557,9 +566,9 @@ class MediaCollectionViewCell: BaseCollectionViewCell, UIScrollViewDelegate {
     // MARK: - Class methods
 
     override class func numberOfColumns(for width: CGFloat) -> CGFloat {
-        if width <= DeviceWidth.iPhone12ProMaxPortrait.rawValue {
+        if width <= DeviceDimensions.iPhone14ProMaxPortrait.rawValue {
             return 1
-        } else if width <= DeviceWidth.iPadLandscape.rawValue {
+        } else if width <= DeviceDimensions.iPadLandscape.rawValue {
             return 2
         } else {
             return 3
