@@ -1,10 +1,11 @@
 /*****************************************************************************
  * VLC for iOS
  *****************************************************************************
- * Copyright (c) 2017-2018 VideoLAN. All rights reserved.
+ * Copyright (c) 2017-2023 VideoLAN. All rights reserved.
  * $Id$
  *
  * Authors: Carola Nitz <caro # videolan.org>
+ *          Felix Paul Kühne <fkuehne # videolan.org>
  *
  * Refer to the COPYING file of the official project for license.
  *****************************************************************************/
@@ -29,6 +30,7 @@
         self.albumName = @"";
         self.artworkImage = nil;
         self.isAudioOnly = NO;
+        self.identifier = nil;
     }
     return self;
 }
@@ -49,6 +51,7 @@
         self.albumName = media.album.title;
         self.artworkImage = [media thumbnailImage];
         self.isAudioOnly = ([media subtype] == VLCMLMediaSubtypeAlbumTrack || media.videoTracks.count == 0) ? YES : NO;
+        self.identifier = @(media.identifier);
     } else { // We're streaming something
         [self fillFromMetaDict:mediaPlayer];
         if (!self.artworkImage) {
@@ -60,16 +63,16 @@
         [self checkIsAudioOnly:mediaPlayer];
     }
 
+    self.descriptiveTitle = nil;
     if (self.isAudioOnly) {
         if (self.artworkImage) {
             if (self.artist)
-                self.title = [self.title stringByAppendingFormat:@" — %@", self.artist];
+                self.descriptiveTitle = [self.title stringByAppendingFormat:@" — %@", self.artist];
             if (self.albumName)
-                self.title = [self.title stringByAppendingFormat:@" — %@", self.albumName];
+                self.descriptiveTitle = [self.title stringByAppendingFormat:@" — %@", self.albumName];
         }
         if (self.title.length < 1)
             self.title = [[mediaPlayer.media url] lastPathComponent];
-
     }
     [self updatePlaybackRate:mediaPlayer];
 
@@ -127,7 +130,11 @@
     VLCMediaMetaData *metadata = mediaPlayer.media.metaData;
 
     if (metadata) {
-        self.title = metadata.title;
+        if (metadata.nowPlaying != nil) {
+            self.title = metadata.nowPlaying;
+        } else {
+            self.title = metadata.title;
+        }
         self.artist = metadata.artist;
         self.albumName = metadata.album;
         self.trackNumber = @(metadata.trackNumber);
@@ -162,6 +169,7 @@
         currentlyPlayingTrackInfo[MPNowPlayingInfoPropertyIsLiveStream] = @(duration.intValue <= 0);
         currentlyPlayingTrackInfo[MPNowPlayingInfoPropertyMediaType] = _isAudioOnly ? @(MPNowPlayingInfoMediaTypeAudio) : @(MPNowPlayingInfoMediaTypeVideo);
         currentlyPlayingTrackInfo[MPNowPlayingInfoPropertyPlaybackProgress] = self.position;
+        currentlyPlayingTrackInfo[MPNowPlayingInfoPropertyExternalContentIdentifier] = self.identifier;
     }
     currentlyPlayingTrackInfo[MPNowPlayingInfoPropertyElapsedPlaybackTime] = self.elapsedPlaybackTime;
     currentlyPlayingTrackInfo[MPNowPlayingInfoPropertyPlaybackRate] = self.playbackRate;
@@ -175,8 +183,16 @@
 
 #if TARGET_OS_IOS
     if (self.artworkImage) {
+        MPMediaItemArtwork *mpartwork;
+        if (@available(iOS 10.0, *)) {
+            mpartwork = [[MPMediaItemArtwork alloc] initWithBoundsSize:self.artworkImage.size
+                                                        requestHandler:^UIImage * _Nonnull(CGSize size) {
+                return self.artworkImage;
+            }];
+        } else {
+            mpartwork = [[MPMediaItemArtwork alloc] initWithImage:self.artworkImage];
+        }
         @try {
-            MPMediaItemArtwork *mpartwork = [[MPMediaItemArtwork alloc] initWithImage:self.artworkImage];
             currentlyPlayingTrackInfo[MPMediaItemPropertyArtwork] = mpartwork;
         } @catch (NSException *exception) {
             currentlyPlayingTrackInfo[MPMediaItemPropertyArtwork] = nil;
