@@ -19,9 +19,7 @@
 
 @interface VLCHTTPUploaderController : NSObject
 
-+ (nonnull instancetype)sharedInstance;
-
-@property (readonly) NSString *nameOfUsedNetworkInterface;
+@property (readonly, nullable) NSString *nameOfUsedNetworkInterface;
 @property (nonatomic, readonly) BOOL isReachable;
 @property (nonatomic, readwrite, nullable) MediaLibraryService *medialibrary;
 
